﻿using System;
using System.IO;
using System.Linq;
using DataCopyBrowser.Classes;
using DataCopyBrowser.Constants;

namespace DataCopyBrowser.Models
{
    /// <summary>
    /// Model
    /// </summary>
    public sealed class FileCopyJobModel
    {
        private readonly FileCopyJobStatus _modelStatus = new FileCopyJobStatus();

        private string _srcDir = string.Empty;

        private string _dstDir = string.Empty;

        public event EventHandler OnStatusChanged;

        public string SrcDir
        {
            get => _srcDir;
            set
            {
                _srcDir = value;
                StateChanged();
            }
        }

        public string DstDir
        {
            get => _dstDir;
            set
            {
                _dstDir = value;
                StateChanged();
            }
        }

        public FileCopyJobStatus Status => _modelStatus;

        public void Copy()
        {
            var srcFilePaths = Directory.GetFiles(SrcDir);
            _modelStatus.NumOfFilesCopied = 0;
            foreach (var srcFilePath in srcFilePaths)
            {
                var dstFileName = Path.GetFileName(srcFilePath);
                var dstFilePath = Path.Combine(_dstDir, dstFileName);
                if (!File.Exists(dstFilePath))
                {
                    try
                    {
                        File.Copy(srcFilePath, dstFilePath);
                        ++_modelStatus.NumOfFilesCopied;
                    }
                    catch { }
                }

                if (_modelStatus.NumOfFilesCopied > 0)
                    _modelStatus.Code = StatusCode.CopyCompleted;
                else
                    _modelStatus.Code = StatusCode.FailedToCopy;

                RaiseStatusChanged();
            }
        }

        public void StateChanged()
        {
            if (string.IsNullOrEmpty(_srcDir) || !Directory.Exists(_srcDir))
                _modelStatus.Code = StatusCode.SrcDirError;
            else if (string.IsNullOrEmpty(_dstDir) || !Directory.Exists(_dstDir))
                _modelStatus.Code = StatusCode.DstDirError;
            else if (Directory.GetFiles(_srcDir).Length == 0)
                _modelStatus.Code = StatusCode.NoSrcFiles;
            else
                _modelStatus.Code = StatusCode.Ready;

            RaiseStatusChanged();
        }

        private void RaiseStatusChanged() => OnStatusChanged?.Invoke(this, EventArgs.Empty);
    }
}