﻿using System;
using DataCopyBrowser.Classes;
using DataCopyBrowser.Constants;
using DataCopyBrowser.Models;

namespace DataCopyBrowser.ViewModels
{
    /// <summary>
    /// ViewModel
    /// </summary>
    public sealed class MainWindowViewModel : NotificationBase
    {
        private readonly FileCopyJobModel _model;

        public MainWindowViewModel(FileCopyJobModel model)
        {
            _model = model;

            _model.OnStatusChanged += (o, e) =>
            {
                NotifyPropChanged(nameof(SrcDir));
                NotifyPropChanged(nameof(DstDir));
                NotifyPropChanged(nameof(Status));
                CopyCmd.NotifyChanged();
            };

            CopyCmd = new RelayCommand(
                (_) => _model.Status.Code != StatusCode.NoSrcFiles,
                (_) =>
                {
                    if (CopyConfirmation())
                        _model.Copy();
                });

            RefreshCmd = new RelayCommand(
                (_) => true,
                (_) =>
                {
                    RefreshView();
                    _model.StateChanged();
                    CopyCmd.NotifyChanged();
                });
        }

        public RelayCommand CopyCmd { get; }

        public RelayCommand RefreshCmd { get; }

        public string SrcDir => _model.SrcDir;

        public string DstDir => _model.DstDir;

        public FileCopyJobStatus Status => _model.Status;

        public Func<bool> CopyConfirmation { get; set; } = () => false;

        public Action RefreshView { get; set; } = () => { };
    }
}