﻿using System;
using System.Windows;
using DataCopyBrowser.Models;
using DataCopyBrowser.ViewModels;

namespace DataCopyBrowser.Views
{
    /// <summary>
    /// View
    /// </summary>
    public sealed partial class MainWindow : Window
    {
        private readonly MainWindowViewModel _viewModel;

        private readonly FileCopyJobModel _model;

        public MainWindow(string[] args)
        {
            InitializeComponent();

            wb1.Navigating += (o, e) => e.Cancel = wb1.Source != null && wb1.Source != e.Uri;
            wb2.Navigating += (o, e) => e.Cancel = wb2.Source != null && wb2.Source != e.Uri;

            _model = new FileCopyJobModel();

            _viewModel = new MainWindowViewModel(_model);

            DataContext = _viewModel;

            _viewModel.PropertyChanged += (o, e) =>
            {
                switch (e.PropertyName)
                {
                    case nameof(MainWindowViewModel.SrcDir):
                        if (_model.SrcDir.Length > 0)
                            wb1.Navigate(new Uri(_model.SrcDir));
                        break;

                    case nameof(MainWindowViewModel.DstDir):
                        if (_model.DstDir.Length > 0)
                            wb2.Navigate(new Uri(_model.DstDir));
                        break;
                }
            };

            _viewModel.CopyConfirmation = () =>
            {
                return MessageBox.Show(this, "ファイルをコピーしますか？", "確認", MessageBoxButton.YesNo, MessageBoxImage.Question, MessageBoxResult.No) == MessageBoxResult.Yes;
            };

            _viewModel.RefreshView = () =>
            {
                wb1.Refresh();
                wb2.Refresh();
            };

            Loaded += (o, e) =>
            {
                _model.SrcDir = args[0];
                _model.DstDir = args[1];
            };
        }
    }
}